@@ -49,23 +49,6 @@ def dt_to_org(datim):
             return datim
     return due_date.strftime("%Y-%m-%d %a %H:%M")
 
-# def dt_to_org(datim):
-#     """
-#     from T Z to <2025-06-30 Mon 00:00>
-#     """
-#     due_str = datim # item['due']    # e.g. '2025-07-01T00:00:00.000Z'
-#     due_date = dt.datetime.strptime(due_str, "%Y-%m-%dT%H:%M:%S.%fZ").date()  # compare to today etc..
-#     p_date =  due_date.strftime("%Y-%m-%d")
-#     p_time =  due_date.strftime("%H:%M:%S")
-#     p_wday =  due_date.strftime("%F")
-#     #
-#     result = due_date.strftime("%Y-%m-%d %a %H:%M")
-#     return result
-#     #
-#     due_str = due_str.split("T")[0]
-#     # plain date
-#     today = dt.datetime.now(dt.timezone.utc).date()
-#     tomorrow = today + dt.timedelta(days=1)
 
 
 # ================================================================================
@@ -92,60 +75,12 @@ def tasks_read_remote(service, TASKLIST1):
                     "status": item.get("status", "needsAction"),
                     "notes": item.get("notes", ""),
                 }
+                #  *** ID  ***
+                #print(f"D...  {task['title']}  ...  {item.get('id')} ")
                 tasks_remote[v].append(task)
         except HttpError as err:
             print("X...", err)
     return tasks_remote
-    # TASKS_REMOTE = []
-    # #print("D... ============================== Parsing tasklists ===")
-    # TASKS_REMOTE.append("* GOOGLE TASKS")
-    # for k, v in TASKLIST1.items():
-    #     TASKS_REMOTE.append(f"** {v}" )
-    #     try:
-    #         #service = build("tasks", "v1", credentials=creds)
-    #         # Call the Tasks API
-    #         results = service.tasks().list(tasklist=k).execute()
-    #         items = results.get("items", [])
-
-    #         #print()
-    #         for item in items:
-
-    #             if 'status' in item:
-    #                 if item['status'] == "completed":
-    #                     #print(f"{fg.slategray}     - {item['title']} : STAT: {item['status']}    {fg.default}")
-    #                     continue
-
-    #             TASKS_REMOTE.append(f"*** TODO {item['title']}")
-    #             if 'due' in item:
-    #                 s_scheduled = dt_to_org(item['due'])
-    #                 TASKS_REMOTE.append(f"SCHEDULED: <{s_scheduled}>")
-    #             s_updated = dt_to_org(item['updated'])
-    #             TASKS_REMOTE.append(f"UPDATED: [{s_updated}]") # inactive timestamp
-    #             if 'status' in item:
-    #                 if item['status'] != "needsAction":
-    #                     TASKS_REMOTE.append(f"            - STAT: {item['status']}    ")
-    #             if 'due' in item:
-    #                 s_scheduled = dt_to_org(item['due'])
-    #                 due_str = item['due']    # e.g. '2025-07-01T00:00:00.000Z'
-    #                 due_date = dt.datetime.strptime(due_str, "%Y-%m-%dT%H:%M:%S.%fZ").date()
-    #                 #due_str = due_str.split("T")[0]
-    #                 today = dt.datetime.now(dt.timezone.utc).date()
-    #                 tomorrow = today + dt.timedelta(days=1)
-    #                 if due_date == today:
-    #                     TASKS_REMOTE.append(f"             -  Due today     ") # The allow day only via API
-    #                 elif due_date == tomorrow:
-    #                     TASKS_REMOTE.append(f"             -  Due tomorrow  ") # They let day only
-    #                 elif due_date < today:
-    #                     TASKS_REMOTE.append(f"             -  Due in the PAST    {due_str}") # They let day only
-    #                 else:
-    #                     #print("Due on", due_date)
-    #                     TASKS_REMOTE.append(f"             - DUE : {due_str}   ")
-    #             if 'notes' in item:
-    #                 TASKS_REMOTE.append(f"             - NOTES: {item['notes']}    ")
-    #             #results = service.tasks().get(tasklist=k, task=item['id'])
-    #     except HttpError as err:
-    #         print("X...", err)
-    # return TASKS_REMOTE
 
 def dict2org(tasks_dict):
     """
@@ -153,8 +88,10 @@ def dict2org(tasks_dict):
     """
     lines = ["* GOOGLE TASKS"]
     for tasklist, tasks in tasks_dict.items():
+        lines.append("")
         lines.append(f"** {tasklist}")
         for t in tasks:
+            lines.append("")
             lines.append(f"*** TODO {t['title']}")
             if t.get("due"):
                 due_org = dt_to_org(t["due"])
@@ -162,7 +99,9 @@ def dict2org(tasks_dict):
             if t.get("updated"):
                 #updated_org = dt_to_org(t["updated"])
                 #lines.append(f"UPDATED: [{updated_org}]")
-                lines.append(f"UPDATED: [{t['updated']}]")  # store full ISO timestamp
+                notsoISO = t['updated']
+                notsoISO = notsoISO.replace("T", " ") # remove T for org
+                lines.append(f"UPDATED: [{notsoISO}]")  # store full ISO timestamp
             if t.get("status") and t["status"] != "needsAction":
                 lines.append(f"            - STAT: {t['status']}")
             if t.get("notes"):
@@ -179,6 +118,9 @@ def dict2org(tasks_dict):
 # --------------------------------------------------------------------------------
 
 def org2dict(org_lines):
+    """
+    convert due to the T Z format
+    """
     tasks_dict = {}
     current_tasklist = None
     current_task = None
@@ -200,6 +142,7 @@ def org2dict(org_lines):
             current_task = {"title": line[8:].strip(), "due": None, "updated": None, "status": "needsAction", "notes": ""}
         elif line.startswith("SCHEDULED: <") and current_task:
             current_task["due"] = line[len("SCHEDULED: <"):-1]
+            current_task["due"] = current_task["due"].split()[0] + "T00:00:00.000Z"
         #elif line.startswith("DEADLINE: <") and current_task:
         #    current_task["due"] = line[len("DEADLINE: <"):-1]
         elif line.startswith("UPDATED: [") and current_task:
@@ -210,42 +153,15 @@ def org2dict(org_lines):
             current_task["notes"] = line.split(":")[1].strip()
         elif current_task:
             if "notes" in current_task:
-                current_task["notes"] = f'{current_task["notes"]}\n{line}'
+                if line != "":
+                    current_task["notes"] = f'{current_task["notes"]}\n{line}'
             else:
-                current_task["notes"] = line
+                if line != "":
+                    current_task["notes"] = line
     # Add last task if any
     if current_task and current_tasklist:
         tasks_dict[current_tasklist].append(current_task)
     return tasks_dict
-    # """
-    # Parses org-mode lines into nested dict {tasklist: [tasks]}.
-    # """
-    # tasks_dict = {}
-    # current_tasklist = None
-    # current_task = None
-    # for line in org_lines:
-    #     line = line.strip()
-    #     if line.startswith("* GOOGLE TASKS"):
-    #         continue
-    #     elif line.startswith("** "):
-    #         current_tasklist = line[3:]
-    #         tasks_dict[current_tasklist] = []
-    #     elif line.startswith("*** TODO "):
-    #         if current_task:
-    #             tasks_dict[current_tasklist].append(current_task)
-    #         current_task = {"title": line[8:], "due": None, "updated": None, "status": "needsAction", "notes": ""}
-    #     elif line.startswith("SCHEDULED: <") and current_task:
-    #         current_task["due"] = line[len("SCHEDULED: <"):-1]
-    #     elif line.startswith("UPDATED: [") and current_task:
-    #         current_task["updated"] = line[len("UPDATED: ["):-1]  # read full ISO timestamp
-    #         # current_task["updated"] = line[len("UPDATED: ["):-1]
-    #     elif line.strip().startswith("- STAT:") and current_task:
-    #         current_task["status"] = line.split(":")[1].strip()
-    #     elif line.strip().startswith("- NOTES:") and current_task:
-    #         current_task["notes"] = line.split(":")[1].strip()
-    # if current_task and current_tasklist:
-    #     tasks_dict[current_tasklist].append(current_task)
-    # return tasks_dict
 
 def tasks_read_file(filepath):
     with open(filepath, "r") as f:
@@ -253,35 +169,6 @@ def tasks_read_file(filepath):
     return org2dict(lines)
 
 
-# def tasks_read_file(filepath="tasks_local.org"):
-#     """
-#     Reads local tasks from an org-mode formatted file.
-#     Returns a list of task dicts with keys: title, due, updated, status, notes.
-#     """
-#     if not os.path.exists(filepath):
-#         print(f"X... NO FILE {filepath}")
-#         sys.exit(0)
-#     tasks = []
-#     current_task = None
-#     with open(filepath, "r") as f:
-#         for line in f:
-#             line = line.strip()
-#             if line.startswith("*** TODO "):
-#                 if current_task:
-#                     tasks.append(current_task)
-#                 current_task = {"title": line[8:], "due": None, "updated": None, "status": "needsAction", "notes": None}
-#             elif line.startswith("SCHEDULED: <") and current_task:
-#                 # parse date inside <>
-#                 current_task["due"] = line[len("SCHEDULED: <"):-1]
-#             elif line.startswith("UPDATED: [") and current_task:
-#                 current_task["updated"] = line[len("UPDATED: ["):-1]
-#             elif line.strip().startswith("- STAT:") and current_task:
-#                 current_task["status"] = line.split(":")[1].strip()
-#             elif line.strip().startswith("- NOTES:") and current_task:
-#                 current_task["notes"] = line.split(":")[1].strip()
-#         if current_task:
-#             tasks.append(current_task)
-#     return tasks
 
 
 # ================================================================================
@@ -296,6 +183,9 @@ def tasks_compare_rl(remote_dict, local_dict):
     to_update = []
     to_push_new = []
 
+    # ---- this part I dont care.....
+    print(fg.darkslateblue)
+    print("_" * 60, " no action with these:")
     for tasklist, remote_tasks in remote_dict.items():
         if tasklist in local_dict:
             local_tasks = local_dict[tasklist]
@@ -307,7 +197,7 @@ def tasks_compare_rl(remote_dict, local_dict):
                     #print(f"         /{li['title']}/")
                     if (ri['title'] == li['title']):
                         present = True
-                        if ri['updated'] == li['updated']:
+                        if (ri['notes'].replace(" ", "") == li['notes'].replace(" ", "") ) and (ri['due'] == li['due']) :
                         #print(ri['title'], "ok")
                             needsupdate = False
                 if not present:
@@ -316,7 +206,10 @@ def tasks_compare_rl(remote_dict, local_dict):
                     print(f"r2l... @ {tasklist:20s}   U   {ri['title']}")
         else:
             print("X... no tasklist {tasklist} in local")
-    print("_" * 60)
+
+
+    print(fg.default)
+    print("_" * 15, "L", "_" * 20, "R", "_" * 15,"starting local->remote:")
 
     for tasklist, local_tasks in local_dict.items():
         if tasklist in remote_dict:
@@ -329,14 +222,23 @@ def tasks_compare_rl(remote_dict, local_dict):
                     #print(f"         /{li['title']}/")
                     if (ri['title'] == li['title']):
                         present = True
-                        if ri['updated'] == li['updated']:
+                        if (  ri['notes'].replace(" ", "") == li['notes'].replace(" ", "")) and (ri['due'] == li['due']) :
                             needsupdate = False
                         #print(ri['title'], "ok")
+                # ------------------- PRINT ALL INTENTIONS ------------
                 if not present:
-                    print(f"l2r... @ {tasklist:20s}   #   {li['title']}")
+                    print(f"l2r... @ {tasklist:20s}   >   {li['title']}")
                     to_push_new.append( (tasklist, li['title']) )
                 elif needsupdate:
                     print(f"l2r... @ {tasklist:20s}   U   {li['title']}")
+                    if  li['notes'].replace(" ", "") != "":
+                        print(f".           {li['notes']}")
+                    if  ri['notes'].replace(" ", "") != "":
+                        print(f".                                  {ri['notes']}")
+                    if li['due'] is not None:
+                        print(f",           {li['due']}")
+                    if ri['due'] is not None:
+                        print(f",                                  {ri['due']}")
                     to_update.append( (tasklist, li['title']) )
         else:
             print("X... no tasklist {tasklist} in remote")
@@ -391,10 +293,86 @@ def add_tasks_to_remote(service, TASKLIST1, local_dict, tasks_to_add):
             print(f"Failed to add task '{task_title}': {err}")
 
 
+# ================================================================================
+#  UPDATE REMOTE
+# --------------------------------------------------------------------------------
 
+def update_remote_task(service, TASKLIST1, local_dict, tasklist_title, task_title):
+    """
+    Update remote task matching (tasklist_title, task_title) with local due and notes if changed.
+    """
+    # Map tasklist title to ID
+    title_to_id = {v: k for k, v in TASKLIST1.items()}
+    tasklist_id = title_to_id.get(tasklist_title)
+    if not tasklist_id:
+        print(f"Tasklist '{tasklist_title}' not found.")
+        return
+
+    # Get local task
+    local_tasks = local_dict.get(tasklist_title, [])
+    local_task = next((t for t in local_tasks if t["title"] == task_title), None)
+    if not local_task:
+        print(f"Local task '{task_title}' not found in '{tasklist_title}'.")
+        return
+
+    # Find remote task by listing tasks in tasklist
+    try:
+        results = service.tasks().list(tasklist=tasklist_id).execute()
+        remote_tasks = results.get("items", [])
+    except HttpError as err:
+        print(f"Failed to list remote tasks: {err}")
+        return
+
+    remote_task = next((t for t in remote_tasks if t["title"] == task_title), None)
+    if not remote_task:
+        print(f"Remote task '{task_title}' not found in '{tasklist_title}'.")
+        return
+
+    # Prepare update body with changed fields
+    body = {}
+    changed = False
+
+    # Compare and update 'due'
+    local_due = local_task.get("due")
+    remote_due = remote_task.get("due")
+    if local_due != remote_due:
+        # Convert local_due to RFC3339 if needed
+        if local_due:
+            try:
+                dt_obj = dt.datetime.strptime(local_due, "%Y-%m-%dT%H:%M:%S.%fZ")
+            except ValueError:
+                dt_obj = dt.datetime.strptime(local_due, "%Y-%m-%d %a %H:%M")
+            body["due"] = dt_obj.strftime("%Y-%m-%dT%H:%M:%S.000Z")
+        else:
+            body["due"] = None
+        changed = True
+
+    # Compare and update 'notes'
+    local_notes = local_task.get("notes", "")
+    remote_notes = remote_task.get("notes", "")
+    if local_notes.replace(" ", "")!= remote_notes.replace(" ", ""):
+        body["notes"] = local_notes
+        changed = True
+
+    if not changed:
+        print(f"No changes detected for task '{task_title}'.")
+        return
+
+    # Include title and status to avoid overwriting
+    body["title"] = task_title
+    body["status"] = remote_task.get("status", "needsAction")
+    body['id'] = remote_task["id"]
+    body['notes'] = local_task['notes']
+
+    try:
+        #print(tasklist_id, "task=", remote_task["id"])
+        service.tasks().update(tasklist=tasklist_id, task=remote_task["id"], body=body).execute()
+        print(f"Updated task '{task_title}' in '{tasklist_title}'.")
+    except HttpError as err:
+        print(f"Failed to update task '{task_title}': {err}")
 
 # ================================================================================
-#
+# MAIN
 # --------------------------------------------------------------------------------
 
 #@click.command()
@@ -476,16 +454,18 @@ def main(command):
 
 
 
-@click.group()
-def cli():
-    pass
+#@click.group()
+#def cli():
+#    pass
 
 
 # ================================================================================
-#
+# IMPORT MAIN
 # --------------------------------------------------------------------------------
 
-@click.command()
+#@click.command()
+#@click.argument("command", default="rprint")
+#def main_import(command):
 def main_import(command="rprint"):
     """Shows basic usage of the Tasks API.
     Prints the title and ID of the first 10 task lists.
@@ -535,14 +515,15 @@ def main_import(command="rprint"):
         #print(tarem)
         print()
         for i in dict2org(tarem): print(i)
-
+    else:
+        print(f"X... command not recognized /{command}/")
 
 # ================================================================================
-#
+#  EXPORT MAIN
 # --------------------------------------------------------------------------------
 
-@click.command()
-@click.argument('filename',  required=True)
+#@click.command()
+#@click.argument('filename',  required=True)
 def main_export(filename, command="rlcomp"):
     """Shows basic usage of the Tasks API.
     Prints the title and ID of the first 10 task lists.
@@ -581,7 +562,8 @@ def main_export(filename, command="rlcomp"):
 
         #print("D... ===============================Task lists:")
         for item in items:
-            #print(f"D...   * {item['title']} ({item['id']})")
+            #   * ID *****
+            # print(f"D...   * {item['title']} ({item['id']})")
             TASKLIST[item['id']] = item['title']
     except HttpError as err:
         print(err)
@@ -604,24 +586,52 @@ def main_export(filename, command="rlcomp"):
     #     for i in dict2org(res): print(i)
     if command == "rlcomp" or command == "rl":
         tarem = tasks_read_remote(service, TASKLIST)
+        if not os.path.exists(filename):
+            print(f"X... cannot find org  file {filename}")
+            sys.exit(1)
+        else:
+            print(f"i... going to export ....  {filename}")
         taloc = tasks_read_file(filename)
+        #print(taloc)
         to_push_new, to_update = tasks_compare_rl(tarem, taloc)
-        print("TO PUSH NEW")
-        print(to_push_new)
-        add_tasks_to_remote(service, TASKLIST, taloc, to_push_new)
-        #
-        #print("TO UPDATE")
-        #print(to_update)
+        print()
+        print("_____________________ UPDATING REMOTE __________________")
+        if len(to_push_new) == 0:
+            print("i... nothing new to push.... ")
+        else:
+            print("TO_PUSH_NEW:")
+            print(to_push_new)
+            add_tasks_to_remote(service, TASKLIST, taloc, to_push_new)
+        print()
+
+        if len(to_update) == 0:
+            print("i... nothing to update")
+        else:
+            print("TO UPDATE:   (not implemented yet)")
+            print(to_update)
+            for ii in to_update:
+                update_remote_task(service, TASKLIST, taloc, ii[0], ii[1])
+
         #print("CHANGE")
         #print(res['to_update'])
     # else:
     #     print("X... unknown command ")
 
 
-
-cli.add_command(main_import, name='import')
-cli.add_command(main_export, name='export')
-
+@click.command()
+@click.argument('action')
+@click.argument('filename', default=None)
+def main(action, filename):
+    #print(action)
+    if action == 'import':
+        #print(action)
+        main_import()
+    else:
+        print("export")
+        if filename is None:
+            print("X... give me filename")
+        main_export(filename)
+    print("finish")
 
 if __name__ == "__main__":
-    cli()
+    main()
